@@ -157,13 +157,13 @@ class SlappResponseObject:
         groups = SlappResponseObject.get_grouped_sources(sources)
         message = []
         for tourney, simple_sources in groups.items():
-            simple_sources.sort(reverse=True)
             group_key = tourney + ': ' if tourney else ''
             group_value_array = list(set(
                 [simple_source.get_linked_date_display() for simple_source in simple_sources]
                 if group_key
                 else [simple_source.get_linked_name_display() for simple_source in simple_sources]
             ))
+            group_value_array.sort(reverse=True)
             separator = ', ' if group_key else '\n'
             group_value = separator.join(group_value_array)
             message.append(f"{group_key}{group_value}")
